@@ -50,9 +50,9 @@ class VariableOsAudio(Variable):
         if "pulseaudio" in avail:
             audio = getValueFromCmdLine(CmdlineParams.Calculate,
                                         CmdlineParams.Audio)
-            if audio and audio == "alsa":
-                return "alsa"
-            return "pulseaudio"
+
+            if audio and audio == "pulseaudio":
+                return "pulseaudio"
         return "alsa"
 
     def choice(self):
@@ -77,9 +77,10 @@ class VariableOsAudioAvailable(Variable):
     type = "list"
 
     def get(self):
-        mapAudioConf = (('pulseaudio', 'media-sound/pulseaudio',
-                         _("PulseAudio")),
-                        ('alsa', None, _('ALSA')))
+        mapAudioConf = (
+            ('alsa', None, _('ALSA')),
+            ('pulseaudio', 'media-sound/pulseaudio', _("PulseAudio")),
+        )
         image = self.Get('cl_image')
         if image:
             with image as distr:
